@@ -51,10 +51,10 @@ class Q_DECL_EXPORT SensorAgent : public QObject
 
   public:
     explicit SensorAgent( SensorManager *sm );
-    virtual ~SensorAgent();
+    ~SensorAgent() override;
 
     virtual bool start( const QString &host, const QString &shell,
-                        const QString &command = "", int port = -1 ) = 0;
+                        const QString &command = QLatin1String(""), int port = -1 ) = 0;
 
     /**
       This function should only be used by the SensorManager and
