@@ -34,7 +34,7 @@
 class QPaintEvent;
 class QResizeEvent;
 
-struct KSignalPlotterPrivate;
+class KSignalPlotterPrivate;
 
 //Make sure only declare KLocalizedString once
 #ifndef KGRAPHICSSIGNALPLOTTER_H
@@ -91,8 +91,8 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
   Q_PROPERTY(int fillOpacity READ fillOpacity WRITE setFillOpacity)
 
   public:
-    KSignalPlotter( QWidget *parent = 0);
-    virtual ~KSignalPlotter();
+    KSignalPlotter( QWidget *parent = nullptr);
+    ~KSignalPlotter() override;
 
     /** \brief Add a new line to the graph plotter, with the specified color.
      *
@@ -449,14 +449,14 @@ class Q_DECL_EXPORT KSignalPlotter : public QWidget
 
   protected:
     /* Reimplemented */
-    virtual void resizeEvent( QResizeEvent* );
-    virtual void paintEvent( QPaintEvent* );
-    virtual QSize sizeHint() const;
-    virtual void changeEvent ( QEvent * event );
+    void resizeEvent( QResizeEvent* ) override;
+    void paintEvent( QPaintEvent* ) override;
+    QSize sizeHint() const override;
+    void changeEvent ( QEvent * event ) override;
 
   private:
     KSignalPlotterPrivate * const d;
-    friend struct KSignalPlotterPrivate;
+    friend class KSignalPlotterPrivate;
 };
 
 #endif
